"""Constants module."""

ABSOLUTE_SUPPORT = "abs support"
ABSOLUTE_EXCEPTIONS = "abs exceptions"
NOT_APPLICABLE = "not applicable"
CONFIDENCE = "confidence"
SUPPORT = "support"
ADDED_VALUE = "added value"
CASUAL_CONFIDENCE = "casual confidence"
CASUAL_SUPPORT = "casual support"
CERTAINTY_FACTOR = "certainty factor"
CONVICTION = "conviction"
COSINE = "cosine"
CONFIRMED_CONFIDENCE = "confirmed confidence"
LIFT = "lift"
RULE_POWER_FACTOR = "rule power factor"

RULE_ID = "rule_id"
RULE_GROUP = "rule_group"
RULE_DEF = "rule_definition"
RULE_STATUS = "rule_status"
RULE_VARIABLES = "variables"
ENCODINGS = "encodings"
RESULT = "result"
INDICES = "indices"
LOGGING = "logging"
RESULT_EXPRESSION = "result_expression"

DUNDER_DF = "_df"

VAR_X_AND_Y = "X and Y"
VAR_X_AND_NOT_Y = "X and ~Y"
VAR_NOT_X_AND_NOT_Y = "~X and ~Y"
VAR_X = "X"
VAR_NOT_X = "~X"
VAR_Y = "Y"
VAR_NOT_Y = "~Y"
VAR_N = "N"
